# Happy Net Box - Python
A command line tool for interacting with [Happy Net Box](https://happynetbox.com/) based on
the node modeule [happynet](https://www.npmjs.com/package/happynet).

# Install
```
$ pip install happynet
```

## Subscribe to users
- Create a file called ~/.happynetbox
- Add a list of @happynetbox handles you want to follow
- Run happynet from your terminal

## Get updates
In your terminal app, run:
```
$ happynet
```
You will see the latest post from each person in your .happynetbox file!

## Links
* [PyPi Project](https://pypi.org/project/happynetpy)
* [Github](https://github.com/spslater/happynetpy)

## Contributing
Help is greatly appreciated. First check if there are any issues open that relate to what you want
to help with. Also feel free to make a pull request with changes / fixes you make.

## License
[MIT License](https://opensource.org/licenses/MIT)
